"""conftest.py for custom test extensions.

This file is optional.  You can define fixtures here that are specific to
your custom tests.  All VIP core fixtures (vip_config, connect_client, etc.)
are available automatically.
"""
